@@ -27,10 +27,3 @@ test_that("isPrimeRcpp generates correct numbers", {
     ## Ensure stdThreadMax returns positive number
     expect_true(stdThreadMax() > 0)
 })
-
-test_that("isPrimeRcpp produces appropriate error messages", {
-    expect_error(isPrimeRcpp(0), "Each element in v must be a positive number")
-    expect_error(isPrimeRcpp(-1), "Each element in v must be a positive number")
-    expect_error(isPrimeRcpp(2^53), "The abs value of each element in v must be less than")
-    expect_error(isPrimeRcpp("100000"), "must be of type numeric or integer")
-})
