@@ -13,10 +13,3 @@ test_that("primeCount generates correct numbers", {
     expect_equal(primeCount(1), 0)
     expect_equal(sapply(1:9, primeCount), c(0,1,2,2,3,3,4,4,4))
 })
-
-test_that("primeCount produces appropriate error messages", {
-    expect_error(primeCount(0), "must be a positive")
-    expect_error(primeCount(-1), "must be a positive")
-    expect_error(primeCount(2^53), "n must be less than")
-    expect_error(primeCount("100000"), "must be of type numeric or integer")
-})
